@@ -35,9 +35,11 @@ def ncdump(src_path: str, long: bool = False, truecolor: bool = True) -> None:
     """
     nc_file = netCDF4.Dataset(src_path, "r")
     if truecolor:
-        console = Console(force_terminal=True, color_system="truecolor", width=200)
+        console = Console(
+            force_terminal=True, color_system="truecolor", width=200, tab_size=4
+        )
     else:
-        console = Console(width=200)
+        console = Console(width=200, tab_size=4)
     print = console.print
 
     def print_ncattr(key: str) -> None:
@@ -64,8 +66,8 @@ def ncdump(src_path: str, long: bool = False, truecolor: bool = True) -> None:
             print(s1 + s2)
 
     # Print the file format
-    if hasattr(nc_file, "file_format"):
-        print(f"[bold white]NetCDF format:[/bold white] {nc_file.file_format}")
+    print(f"[bold white]NetCDF format:[/bold white] {nc_file.file_format}")
+
     # NetCDF global attributes
     nc_attrs = nc_file.ncattrs()
     print("[bold white]NetCDF Global Attributes:[/bold white]")
@@ -74,17 +76,37 @@ def ncdump(src_path: str, long: bool = False, truecolor: bool = True) -> None:
             if repr(nc_file.getncattr(nc_attr)[0]) != repr("\n"):
                 print(
                     "\t[italic white]%s:[/italic white]" % nc_attr,
-                    textwrap.fill(
-                        str(nc_file.getncattr(nc_attr)),
-                        subsequent_indent="\t\t",
-                        break_long_words=False,
-                        break_on_hyphens=False,
+                    "\n\t\t".join(
+                        [
+                            textwrap.fill(
+                                line,
+                                width=90,
+                                tabsize=4,
+                                break_long_words=False,
+                                replace_whitespace=False,
+                                subsequent_indent="\t\t\t",
+                            )
+                            for line in str(nc_file.getncattr(nc_attr)).splitlines()
+                        ]
                     ),
                 )
             else:
                 print(
                     "\t[italic white]%s:[/italic white]" % nc_attr,
-                    textwrap.indent(str(nc_file.getncattr(nc_attr)), "\t\t"),
+                    "\n\t\t".join(
+                        [
+                            textwrap.fill(
+                                line,
+                                width=90,
+                                tabsize=4,
+                                break_long_words=False,
+                                replace_whitespace=False,
+                                subsequent_indent="\t\t\t",
+                            )
+                            for line in str(nc_file.getncattr(nc_attr)).splitlines()
+                        ]
+                    ),
+                    # textwrap.indent(str(nc_file.getncattr(nc_attr)), "\t\t"),
                 )
         except IndexError:
             print(
